==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDetailDescription } from "./WebFloatingPaneResizeMoveEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("OldWidth", "Number:double");
            a.item("NewWidth", "Number:double");
            a.item("OldHeight", "Number:double");
            a.item("NewHeight", "Number:double");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebFloatingPaneResizeMoveEventArgsDetail", () => new WebFloatingPaneResizeMoveEventArgsDetailDescription());
            a.ac("WebFloatingPaneResizeMoveEventArgsDetail", WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDetailDescription } from "./WebFloatingPaneResizeMoveEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldWidth", "Number:double");
            a.item("NewWidth", "Number:double");
            a.item("OldHeight", "Number:double");
            a.item("NewHeight", "Number:double");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebFloatingPaneResizeMoveEventArgsDetail", () => new WebFloatingPaneResizeMoveEventArgsDetailDescription());
            a.ad("WebFloatingPaneResizeMoveEventArgsDetail", WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata;
})();
